pub struct UploadedGoModule {
pub uri: String,
pub file_hashes: Option<FileHashes>,
pub push_timing: Option<TimeSpan>,
pub artifact_registry_package: String,
}Expand description
A Go module artifact uploaded to Artifact Registry using the GoModule directive.
Fields
uri: StringURI of the uploaded artifact.
file_hashes: Option<FileHashes>Hash types and values of the Go Module Artifact.
push_timing: Option<TimeSpan>Output only. Stores timing information for pushing the specified artifact.
artifact_registry_package: StringOutput only. Path to the artifact in Artifact Registry.